@@ -144,6 +144,8 @@ class Device(threading.Thread):
         cfg = {}
         cfg["CFG"] = self._cfg
         for value in self._control_dict.values():
+            if value.cntrl_type == "ALM":
+                continue
             if value.cntrl_type not in cfg:
                 cfg[value.cntrl_type] = []
             cfg[value.cntrl_type].append(value._cfg)
@@ -160,6 +162,8 @@ class Device(threading.Thread):
         reply = self._device_id_str + f"\tCFG\t{dashboard_id}\tDVCE\t" + json.dumps(self._cfg) + "\n"
         dvvw_str = ""
         for value in self._control_dict.values():
+            if value.cntrl_type == "ALM":
+                continue
             if value.cntrl_type == "DVVW":
                 dvvw_str += self._device_id_str + value.get_cfg(data)
             else:
